;; Generated package description from eldoc.el  -*- no-byte-compile: t -*-
(define-package "eldoc" "1.13.0" "Show function arglist or variable docstring in echo area" '((emacs "26.3")) :commit "5f64ba0efbfcbb6dc44add191427aca504b4c3cd" :url "https://elpa.gnu.org/packages/eldoc.html" :authors '(("Noah Friedman" . "friedman@splode.com")) :maintainer '("Noah Friedman" . "friedman@splode.com") :keywords '("extensions"))
